@@ -25,11 +25,10 @@ class PracticeService:
         else:
             request_path = f"/experts/by_user_id/{str(user_id)}"
 
-        response, _ = self.service_provider.fetch_data(request_path)
-        return response
+        return self.service_provider.fetch_data(request_path).data
 
     def is_practice_active(self, practice_id: uuid.UUID) -> bool:
         request_path = f"/practices/{str(practice_id)}/is_active"
-        response, response_code = self.service_provider.fetch_data(
-            request_path)
+        response_code = self.service_provider.fetch_data(
+            request_path).code
         return response_code == status.HTTP_200_OK
