@@ -4,7 +4,7 @@ from pydantic import BaseModel
 
 class Settings(BaseModel):
     PROJECT_BASE_URL: str = os.getenv('PROJECT_BASE_URL', 'localhost:8090')
-    PROJECT_HOST_SCHEME: str = os.getenv('PROJECT_HOST_SCHEME', 'http')
+    PROJECT_HOST_SCHEME: str = os.getenv('PROJECT_HOST_SCHEME', 'https')
     PROJECT_HOST_SERVICE_DICT: str = os.getenv(
         'PROJECT_HOST_SERVICE_DICT', 'service_dict')
     PROJECT_HOST_SERVICE_PATIENTS: str = os.getenv(
